FileId

Struct FileId 

pub struct FileId {
    pub shard: u64,
    pub realm: u64,
    pub num: u64,
    pub checksum: Option<Checksum>,
}
The unique identifier for a file on Hiero.

Fields

shard: u64

The shard number.

realm: u64

The realm number.

num: u64

The file number.

checksum: Option<Checksum>

A checksum if the file ID was read from a user inputted string which inclueded a checksum

Implementations

Source

impl FileId

pub const ADDRESS_BOOK: Self

👎Deprecated:

use get_address_book_file_id_for instead

Address of the public node address book for the current network.

pub const FEE_SCHEDULE: Self

👎Deprecated:

use get_fee_schedule_file_id_for instead

Address of the current fee schedule for the network.

pub const EXCHANGE_RATES: Self

👎Deprecated:

use get_exchange_rates_file_id_for instead

Address of the current exchange rate of HBAR to USD.

pub const fn new(shard: u64, realm: u64, num: u64) -> Self

Create a FileId with the given shard.realm.num.

pub fn get_address_book_file_id_for(realm: u64, shard: u64) -> Self

Address of the public node address book for the current network.

pub fn get_fee_schedule_file_id_for(realm: u64, shard: u64) -> Self

Address of the current fee schedule for the network.

pub fn get_exchange_rates_file_id_for(realm: u64, shard: u64) -> Self

Address of the current exchange rate of HBAR to USD.

pub fn from_bytes(bytes: &[u8]) -> Result<Self>

Create a new FileId from protobuf-encoded bytes.

Errors
pub fn from_solidity_address(address: &str) -> Result<Self>

Create a FileId from a solidity address.

Errors
pub fn to_bytes(&self) -> Vec<u8>

Convert self to a protobuf-encoded Vec<u8>.

pub fn to_solidity_address(&self) -> Result<String>

Convert self into a solidity address

Errors
pub fn to_string_with_checksum(&self, client: &Client) -> String

Convert self to a string with a valid checksum.

pub fn validate_checksum(&self, client: &Client) -> Result<(), Error>

Validates self.checksum (if it exists) for client.

Errors
  • Error::BadEntityId if there is a checksum, and the checksum is not valid for the client’s ledger_id.