#[repr(C)]pub struct TopicId {
pub shard: u64,
pub realm: u64,
pub num: u64,
pub checksum: Option<Checksum>,
}Expand description
The unique identifier for a topic on Hiero.
Fields
shard: u64A non-negative number identifying the shard containing this topic.
realm: u64A non-negative number identifying the realm within the shard containing this topic.
num: u64A non-negative number identifying the entity within the realm containing this topic.
checksum: Option<Checksum>A checksum if the topic ID was read from a user inputted string which inclueded a checksum
Implementations
Sourceimpl TopicId
impl TopicId
Sourcepub const fn new(shard: u64, realm: u64, num: u64) -> Self
pub const fn new(shard: u64, realm: u64, num: u64) -> Self
Create a TopicId with the given shard.realm.num.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self>
pub fn from_bytes(bytes: &[u8]) -> Result<Self>
Create a new TopicId from protobuf-encoded bytes.
Errors
Error::FromProtobufif decoding the bytes fails to produce a valid protobuf.Error::FromProtobufif decoding the protobuf fails.
Sourcepub fn from_solidity_address(address: &str) -> Result<Self>
pub fn from_solidity_address(address: &str) -> Result<Self>
Create a TopicId from a solidity address.
Errors
Error::BasicParseifaddresscannot be parsed as a solidity address.
Sourcepub fn to_solidity_address(&self) -> Result<String>
pub fn to_solidity_address(&self) -> Result<String>
Convert self into a solidity address
Errors
Error::BasicParseifself.shardis larger thanu32::MAX.
Sourcepub fn to_string_with_checksum(&self, client: &Client) -> String
pub fn to_string_with_checksum(&self, client: &Client) -> String
Convert self to a string with a valid checksum.
Sourcepub fn validate_checksum(&self, client: &Client) -> Result<()>
pub fn validate_checksum(&self, client: &Client) -> Result<()>
Validates self.checksum (if it exists) for client.
Errors
Error::BadEntityIdif there is a checksum, and the checksum is not valid for the client’sledger_id.