pub type NodeAddressBookQuery = MirrorQuery<NodeAddressBookQueryData>;Expand description
Query for an address book and return its nodes. The nodes are returned in ascending order by node ID.
Aliased Type
pub struct NodeAddressBookQuery { /* private fields */ }Implementations
Sourceimpl NodeAddressBookQuery
impl NodeAddressBookQuery
Sourcepub fn get_file_id(&self) -> FileId
pub fn get_file_id(&self) -> FileId
Returns the file ID of the address book file on the network.
Sourcepub fn file_id(&mut self, id: impl Into<FileId>) -> &mut Self
pub fn file_id(&mut self, id: impl Into<FileId>) -> &mut Self
Sets the ID of the address book file on the network.
Can either be 0.0.101 or 0.0.102. Defaults to 0.0.102.
Sourcepub fn limit(&mut self, limit: u32) -> &mut Self
pub fn limit(&mut self, limit: u32) -> &mut Self
Sets the maximum number of node addresses to receive. Defaults to all.