pub struct FileId {
pub shard: u64,
pub realm: u64,
pub num: u64,
pub checksum: Option<Checksum>,
}Expand description
The unique identifier for a file on Hiero.
Fields
shard: u64The shard number.
realm: u64The realm number.
num: u64The file number.
checksum: Option<Checksum>A checksum if the file ID was read from a user inputted string which inclueded a checksum
Implementations
Sourceimpl FileId
impl FileId
Sourcepub const ADDRESS_BOOK: Self
👎Deprecated: use get_address_book_file_id_for instead
pub const ADDRESS_BOOK: Self
use get_address_book_file_id_for instead
Address of the public node address book for the current network.
Sourcepub const FEE_SCHEDULE: Self
👎Deprecated: use get_fee_schedule_file_id_for instead
pub const FEE_SCHEDULE: Self
use get_fee_schedule_file_id_for instead
Address of the current fee schedule for the network.
Sourcepub const EXCHANGE_RATES: Self
👎Deprecated: use get_exchange_rates_file_id_for instead
pub const EXCHANGE_RATES: Self
use get_exchange_rates_file_id_for instead
Address of the current exchange rate of HBAR to USD.
Sourcepub const fn new(shard: u64, realm: u64, num: u64) -> Self
pub const fn new(shard: u64, realm: u64, num: u64) -> Self
Create a FileId with the given shard.realm.num.
Sourcepub fn get_address_book_file_id_for(realm: u64, shard: u64) -> Self
pub fn get_address_book_file_id_for(realm: u64, shard: u64) -> Self
Address of the public node address book for the current network.
Sourcepub fn get_fee_schedule_file_id_for(realm: u64, shard: u64) -> Self
pub fn get_fee_schedule_file_id_for(realm: u64, shard: u64) -> Self
Address of the current fee schedule for the network.
Sourcepub fn get_exchange_rates_file_id_for(realm: u64, shard: u64) -> Self
pub fn get_exchange_rates_file_id_for(realm: u64, shard: u64) -> Self
Address of the current exchange rate of HBAR to USD.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self>
pub fn from_bytes(bytes: &[u8]) -> Result<Self>
Create a new FileId from protobuf-encoded bytes.
Errors
Error::FromProtobufif decoding the bytes fails to produce a valid protobuf.Error::FromProtobufif decoding the protobuf fails.
Sourcepub fn from_solidity_address(address: &str) -> Result<Self>
pub fn from_solidity_address(address: &str) -> Result<Self>
Create a FileId from a solidity address.
Errors
Error::BasicParseifaddresscannot be parsed as a solidity address.
Sourcepub fn to_solidity_address(&self) -> Result<String>
pub fn to_solidity_address(&self) -> Result<String>
Convert self into a solidity address
Errors
Error::BasicParseifself.shardis larger thanu32::MAX.
Sourcepub fn to_string_with_checksum(&self, client: &Client) -> String
pub fn to_string_with_checksum(&self, client: &Client) -> String
Convert self to a string with a valid checksum.
Sourcepub fn validate_checksum(&self, client: &Client) -> Result<(), Error>
pub fn validate_checksum(&self, client: &Client) -> Result<(), Error>
Validates self.checksum (if it exists) for client.
Errors
Error::BadEntityIdif there is a checksum, and the checksum is not valid for the client’sledger_id.